InMemoryCacheStore class

Simple in-memory implementation of CacheStore.

Implemented types

Constructors

InMemoryCacheStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Remove all entries.
override
containsKey(String key) bool
Whether the store contains key.
override
get(String key) → dynamic
Retrieve a cached value by key, or null if absent.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → void
Remove a single entry.
override
set(String key, dynamic value) → void
Store a value under key.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited