Offline class final
The device is currently offline. No network requests can be fulfilled from the network layer.
- Inheritance
-
- Object
- NetworkState
- Offline
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- queuedRequests → int
-
Number of requests currently waiting in the offline queue.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override