Success<T> class final

An operation completed successfully.

Inheritance

Constructors

Success(T data, {bool fromCache = false})
const

Properties

data → T
The resulting data.
final
fromCache bool
Whether the data was served from cache rather than the network.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override