Syncing class final

The sync engine is replaying queued requests after connectivity was restored.

Inheritance

Constructors

Syncing({int totalRequests = 0, int completedRequests = 0})
const

Properties

completedRequests int
Number of requests that have been successfully replayed so far.
final
hashCode int
The hash code for this object.
no setteroverride
progress double
Progress ratio from 0.0 to 1.0.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalRequests int
Total number of queued requests being synced.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override