CacheFirst class final

Check the cache first. If a valid (non-expired) entry exists, return it immediately. Otherwise, execute the network request and cache the result.

Inheritance

Constructors

CacheFirst()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited