BackoffStrategy class abstract

Abstract interface for back-off strategies.

Implementers
Annotations

Constructors

BackoffStrategy()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delay(int attempt) Duration
Returns the delay before the given attempt (0-indexed).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited