LinearBackoff class

Linear back-off: baseDelay * (attempt + 1).

Inheritance
Annotations

Constructors

LinearBackoff({Duration baseDelay = const Duration(seconds: 1), Duration maxDelay = const Duration(seconds: 30)})
const

Properties

baseDelay Duration
final
hashCode int
The hash code for this object.
no setterinherited
maxDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delay(int attempt) Duration
Returns the delay before the given attempt (0-indexed).
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited