DioInterceptorConfig class

Configuration for NetworkDioInterceptor.

Constructors

DioInterceptorConfig({RetryPolicy retryPolicy = const RetryPolicy(), bool queueWhenOffline = true, bool logRequests = true, bool logResponses = true, bool logErrors = true, Set<int> retryableStatusCodes = const {408, 429, 500, 502, 503, 504}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
logErrors bool
Log errors.
final
logRequests bool
Log outgoing requests.
final
logResponses bool
Log incoming responses.
final
queueWhenOffline bool
When true, requests that fail because the device is offline are enqueued in the RequestQueue for later replay.
final
retryableStatusCodes Set<int>
HTTP status codes that are eligible for automatic retry.
final
retryPolicy RetryPolicy
Retry policy for failed requests.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited