queueWhenOffline property
When true, requests that fail because the device is offline are
enqueued in the RequestQueue for later replay.
Implementation
final bool queueWhenOffline;
When true, requests that fail because the device is offline are
enqueued in the RequestQueue for later replay.
final bool queueWhenOffline;