NetworkManagerConfig class

Configuration for NetworkManager.

Constructors

NetworkManagerConfig({NetworkStrategy defaultStrategy = const NetworkFirst(), Duration defaultCacheTtl = const Duration(minutes: 5), RetryPolicy retryPolicy = const RetryPolicy(), bool autoStart = true})
const

Properties

autoStart bool
Whether to start listening for connectivity automatically on creation.
final
defaultCacheTtl Duration
Default TTL for cached entries.
final
defaultStrategy NetworkStrategy
Default strategy when none is specified on individual requests.
final
hashCode int
The hash code for this object.
no setterinherited
retryPolicy RetryPolicy
Default retry policy for queued requests.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited