InMemoryQueueStore class

Simple in-memory FIFO queue.

Implemented types

Constructors

InMemoryQueueStore()

Properties

all List<QueuedRequest>
All requests currently in the queue (oldest first).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether the queue is empty.
no setteroverride
length int
Number of queued requests.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all queued requests.
override
dequeue() QueuedRequest?
Remove and return the next request, or null if empty.
override
enqueue(QueuedRequest request) → void
Add a request to the end of the queue.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek() QueuedRequest?
Peek at the next request without removing it.
override
remove(String id) bool
Remove a specific request by its id.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited