SyncEngine class
Listens to NetworkStatusMonitor and triggers RequestQueue processing whenever connectivity is restored.
Constructors
- SyncEngine({required NetworkStatusMonitor monitor, required RequestQueue queue, CacheManager? cacheManager, NetworkLogger? logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSyncing → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateStream
→ Stream<
NetworkState> -
no setter
Methods
-
dispose(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void -
syncNow(
) → Future< List< QueueProcessResult> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited