NetworkBuilder class
A widget that rebuilds whenever NetworkManager emits a new state.
NetworkBuilder(
manager: networkManager,
builder: (context, state) {
return switch (state) {
Idle() => Text('Ready'),
Loading() => CircularProgressIndicator(),
Offline() => OfflineBanner(queued: state.queuedRequests),
Syncing() => LinearProgressIndicator(value: state.progress),
Success() => DataView(data: state.data),
Error() => ErrorView(message: state.message),
};
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NetworkBuilder
Constructors
- NetworkBuilder({Key? key, required NetworkManager manager, required Widget builder(BuildContext context, NetworkState state), NetworkState? initialState})
-
Creates a NetworkBuilder.
const
Properties
- builder → Widget Function(BuildContext context, NetworkState state)
-
Builder called with the current NetworkState.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialState → NetworkState?
-
Optional initial state. Defaults to Idle.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- manager → NetworkManager
-
The NetworkManager whose state stream to listen to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited