CacheStore class abstract
Abstraction over the underlying storage mechanism.
The default implementation is InMemoryCacheStore. Users can provide their
own (e.g. SharedPreferences, Hive, Isar) for persistence.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Remove all entries.
-
containsKey(
String key) → bool -
Whether the store contains
key. -
get(
String key) → dynamic -
Retrieve a cached value by
key, ornullif absent. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → void - Remove a single entry.
-
set(
String key, dynamic value) → void -
Store a
valueunderkey. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited