InternetCheckerConfig class
Configuration for InternetChecker.
Constructors
-
InternetCheckerConfig({List<
String> lookupAddresses = const ['google.com', 'cloudflare.com', 'apple.com'], Duration timeout = const Duration(seconds: 3), Duration checkInterval = const Duration(seconds: 10)}) -
const
Properties
- checkInterval → Duration
-
Interval for periodic checks (used by
startPeriodicCheck).final - hashCode → int
-
The hash code for this object.
no setterinherited
-
lookupAddresses
→ List<
String> -
Domains to perform DNS lookups against.
At least one must resolve for the device to be considered online.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
Timeout for each DNS lookup attempt.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited