QueuedRequest class
Represents a single deferred request waiting in the queue.
- Annotations
Constructors
- QueuedRequest({required String id, required Future execute(), RetryPolicy retryPolicy = const RetryPolicy(), String? cacheKey, DateTime? enqueuedAt})
Properties
- cacheKey → String?
-
Optional cache key — if provided, the result will be cached on success.
final
- enqueuedAt → DateTime
-
When this request was added to the queue.
final
- execute → Future Function()
-
The closure that executes the actual request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this request.
final
- retryPolicy → RetryPolicy
-
Retry policy to apply when replaying this request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited